Mechatronics refers to the vehicle level parameters and is specified with a yaml file.

Each key in this file refers to a mechatronics id and each sub key is a specific parameter of that mechatronics type.
